@@ -71,6 +71,7 @@ public interface ScmProvider
      *
      * @param logger The logger
      */
+    @Deprecated
     void addListener( ScmLogger logger );
 
     boolean requiresEditMode();
@@ -155,9 +156,9 @@ public interface ScmProvider
      * @param fileSet    the files to branch. Implementations can also give the changes
      *                   from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
      * @param branchName the branch name to apply to the files
-     * @return
+     * @return TODO
      * @throws ScmException if any
-     * @deprecated use {@link #branch(ScmRepository, ScmFileSet, String, String, ScmBranchParameters)}
+     * @deprecated use {@link #branch(ScmRepository, ScmFileSet, String, ScmBranchParameters)}
      */
     BranchScmResult branch( ScmRepository repository, ScmFileSet fileSet, String branchName )
         throws ScmException;
@@ -170,9 +171,9 @@ public interface ScmProvider
      *                   from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
      * @param branchName the branch name to apply to the files
      * @param message    the commit message used for the tag creation
-     * @return
+     * @return TODO
      * @throws ScmException if any
-     * @deprecated use {@link #branch(ScmRepository, ScmFileSet, String, String, ScmBranchParameters)}
+     * @deprecated use {@link #branch(ScmRepository, ScmFileSet, String, ScmBranchParameters)}
      */
     BranchScmResult branch( ScmRepository repository, ScmFileSet fileSet, String branchName, String message )
         throws ScmException;
@@ -185,7 +186,8 @@ public interface ScmProvider
      * @param fileSet    the files to branch. Implementations can also give the changes from the
      *                   {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
      * @param branchName the branch name to apply to the files
-     * @return
+     * @param scmBranchParameters TODO
+     * @return TODO
      * @throws ScmException if any
      * @since 1.3
      */
@@ -194,7 +196,7 @@ public interface ScmProvider
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system in a certain period of time.
+     * Returns the changes that have happened in the source control system in a certain period of time.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository the source control system
@@ -215,7 +217,7 @@ public interface ScmProvider
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system in a certain period of time.
+     * Returns the changes that have happened in the source control system in a certain period of time.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository the source control system
@@ -235,7 +237,7 @@ public interface ScmProvider
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system in a certain period of time.
+     * Returns the changes that have happened in the source control system in a certain period of time.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository  the source control system
@@ -256,7 +258,7 @@ public interface ScmProvider
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system in a certain period of time.
+     * Returns the changes that have happened in the source control system in a certain period of time.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository  the source control system
@@ -264,7 +266,7 @@ public interface ScmProvider
      *                    from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
      * @param startDate   the start date of the period
      * @param endDate     the end date of the period
-     * @param numDays     the number days before the current time if startdate and enddate are null
+     * @param numDays     the number days before the current time if startDate and endDate are null
      * @param branch      the branch/tag
      * @param datePattern the date pattern use in changelog output returned by scm tool
      * @return The SCM result of the changelog command
@@ -276,7 +278,7 @@ public interface ScmProvider
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system in a certain period of time.
+     * Returns the changes that have happened in the source control system in a certain period of time.
      * This can be adding, removing, updating, ... of files
      *
      * @param scmRequest request wrapping detailed parameters for the changelog command
@@ -288,7 +290,7 @@ public interface ScmProvider
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system between two tags.
+     * Returns the changes that have happened in the source control system between two tags.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository the source control system
@@ -305,7 +307,7 @@ public interface ScmProvider
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system between two tags.
+     * Returns the changes that have happened in the source control system between two tags.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository   the source control system
@@ -323,7 +325,7 @@ public interface ScmProvider
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system between two tags.
+     * Returns the changes that have happened in the source control system between two tags.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository  the source control system
@@ -332,7 +334,7 @@ public interface ScmProvider
      * @param startTag    the start tag
      * @param endTag      the end tag
      * @param datePattern the date pattern use in changelog output returned by scm tool
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated use {@link #changeLog(org.apache.maven.scm.command.changelog.ChangeLogScmRequest)} instead
      */
@@ -342,7 +344,7 @@ public interface ScmProvider
         throws ScmException;
 
     /**
-     * Returns the changes that have happend in the source control system between two tags.
+     * Returns the changes that have happened in the source control system between two tags.
      * This can be adding, removing, updating, ... of files
      *
      * @param repository    the source control system
@@ -351,7 +353,7 @@ public interface ScmProvider
      * @param startRevision the start revision
      * @param endRevision   the end revision
      * @param datePattern   the date pattern use in changelog output returned by scm tool
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated use {@link #changeLog(org.apache.maven.scm.command.changelog.ChangeLogScmRequest)} instead
      */
@@ -363,7 +365,7 @@ public interface ScmProvider
     /**
      * Save the changes you have done into the repository. This will create a new version of the file or
      * directory in the repository.
-     * <p/>
+     * <p>
      * When the fileSet has no entries, the fileSet.getBaseDir() is recursively committed.
      * When the fileSet has entries, the commit is non-recursive and only the elements in the fileSet
      * are committed.
@@ -372,7 +374,7 @@ public interface ScmProvider
      * @param fileSet    the files to check in (sometimes called commit)
      * @param tag        tag or revision
      * @param message    a string that is a comment on the changes that where done
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#checkIn(org.apache.maven.scm.repository.ScmRepository,
      *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, String)}
@@ -383,7 +385,7 @@ public interface ScmProvider
     /**
      * Save the changes you have done into the repository. This will create a new version of the file or
      * directory in the repository.
-     * <p/>
+     * <p>
      * When the fileSet has no entries, the fileSet.getBaseDir() is recursively committed.
      * When the fileSet has entries, the commit is non-recursive and only the elements in the fileSet
      * are committed.
@@ -391,7 +393,7 @@ public interface ScmProvider
      * @param repository the source control system
      * @param fileSet    the files to check in (sometimes called commit)
      * @param message    a string that is a comment on the changes that where done
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     CheckInScmResult checkIn( ScmRepository repository, ScmFileSet fileSet, String message )
@@ -400,7 +402,7 @@ public interface ScmProvider
     /**
      * Save the changes you have done into the repository. This will create a new version of the file or
      * directory in the repository.
-     * <p/>
+     * <p>
      * When the fileSet has no entries, the fileSet.getBaseDir() is recursively committed.
      * When the fileSet has entries, the commit is non-recursive and only the elements in the fileSet
      * are committed.
@@ -409,7 +411,7 @@ public interface ScmProvider
      * @param fileSet    the files to check in (sometimes called commit)
      * @param revision   branch/tag/revision
      * @param message    a string that is a comment on the changes that where done
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     CheckInScmResult checkIn( ScmRepository repository, ScmFileSet fileSet, ScmVersion revision, String message )
@@ -421,7 +423,7 @@ public interface ScmProvider
      * @param repository the source control system
      * @param fileSet    the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} location
      * @param tag        get the version defined by the tag
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#checkOut(org.apache.maven.scm.repository.ScmRepository,
      *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion)}
@@ -434,7 +436,7 @@ public interface ScmProvider
      *
      * @param repository the source control system
      * @param fileSet    the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} location
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     CheckOutScmResult checkOut( ScmRepository repository, ScmFileSet fileSet )
@@ -446,7 +448,7 @@ public interface ScmProvider
      * @param repository the source control system
      * @param fileSet    the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} location
      * @param version    get the version defined by the revision, branch or tag
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     CheckOutScmResult checkOut( ScmRepository repository, ScmFileSet fileSet, ScmVersion version )
@@ -459,7 +461,7 @@ public interface ScmProvider
      * @param scmFileSet    the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} location
      * @param tag           tag or revision
      * @param recursive     whether to check out recursively
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#checkOut(org.apache.maven.scm.repository.ScmRepository,
      *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, boolean)}
@@ -473,7 +475,7 @@ public interface ScmProvider
      * @param scmRepository the source control system
      * @param scmFileSet    the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} location
      * @param recursive     whether to check out recursively
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     CheckOutScmResult checkOut( ScmRepository scmRepository, ScmFileSet scmFileSet, boolean recursive )
@@ -486,7 +488,7 @@ public interface ScmProvider
      * @param scmFileSet    the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} location
      * @param version       get the version defined by the revision, branch or tag
      * @param recursive     whether to check out recursively
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     CheckOutScmResult checkOut( ScmRepository scmRepository, ScmFileSet scmFileSet, ScmVersion version,
@@ -501,7 +503,7 @@ public interface ScmProvider
      *                          location
      * @param version           get the version defined by the revision, branch or tag
      * @param commandParameters parameters
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @since 1.9.6
      */
@@ -516,7 +518,7 @@ public interface ScmProvider
      * @param scmFileSet    the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} location
      * @param startRevision the start revision
      * @param endRevision   the end revision
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#diff(org.apache.maven.scm.repository.ScmRepository,
      *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, org.apache.maven.scm.ScmVersion)}
@@ -531,7 +533,7 @@ public interface ScmProvider
      * @param scmFileSet    the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} location
      * @param startVersion  the start branch/tag/revision
      * @param endVersion    the end branch/tag/revision
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     DiffScmResult diff( ScmRepository scmRepository, ScmFileSet scmFileSet, ScmVersion startVersion,
@@ -544,7 +546,7 @@ public interface ScmProvider
      * @param repository the source control system
      * @param fileSet    the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} location
      * @param tag        get the version defined by the tag
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#export(org.apache.maven.scm.repository.ScmRepository,
      *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion)}
@@ -557,7 +559,7 @@ public interface ScmProvider
      *
      * @param repository the source control system
      * @param fileSet    the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} location
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     ExportScmResult export( ScmRepository repository, ScmFileSet fileSet )
@@ -569,7 +571,7 @@ public interface ScmProvider
      * @param repository the source control system
      * @param fileSet    the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} location
      * @param version    get the version defined by the branch/tag/revision
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     ExportScmResult export( ScmRepository repository, ScmFileSet fileSet, ScmVersion version )
@@ -582,7 +584,7 @@ public interface ScmProvider
      * @param fileSet         the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} location
      * @param tag             get the version defined by the tag
      * @param outputDirectory the directory where the export will be stored
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#export(org.apache.maven.scm.repository.ScmRepository,
      *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, String)}
@@ -597,7 +599,7 @@ public interface ScmProvider
      * @param fileSet         the files are copied to the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} location
      * @param version         get the version defined by the branch/tag/revision
      * @param outputDirectory the directory where the export will be stored
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     ExportScmResult export( ScmRepository repository, ScmFileSet fileSet, ScmVersion version, String outputDirectory )
@@ -608,8 +610,8 @@ public interface ScmProvider
      *
      * @param repository the source control system
      * @param fileSet    the files to be removed
-     * @param message
-     * @return
+     * @param message TODO
+     * @return TODO
      * @throws ScmException if any
      */
     RemoveScmResult remove( ScmRepository repository, ScmFileSet fileSet, String message )
@@ -622,7 +624,7 @@ public interface ScmProvider
      * @param repository the source control system
      * @param fileSet    the files to know the status about. Implementations can also give the changes
      *                   from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     StatusScmResult status( ScmRepository repository, ScmFileSet fileSet )
@@ -635,7 +637,7 @@ public interface ScmProvider
      * @param fileSet    the files to tag. Implementations can also give the changes
      *                   from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
      * @param tagName    the tag name to apply to the files
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated use {@link #tag(ScmRepository, ScmFileSet, String, ScmTagParameters)}
      */
@@ -647,8 +649,8 @@ public interface ScmProvider
      *
      * @param repository the source control system
      * @param fileSet    a fileset with the relevant working directory as basedir
-     * @param parameters
-     * @return
+     * @param parameters TODO
+     * @return TODO
      * @throws ScmException if any
      */
     UntagScmResult untag( ScmRepository repository, ScmFileSet fileSet, CommandParameters parameters )
@@ -662,7 +664,7 @@ public interface ScmProvider
      *                   from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
      * @param tagName    the tag name to apply to the files
      * @param message    the commit message used for the tag creation
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated use {@link #tag(ScmRepository, ScmFileSet, String, ScmTagParameters)}
      */
@@ -677,7 +679,7 @@ public interface ScmProvider
      *                         from the {@link org.apache.maven.scm.ScmFileSet#getBasedir()} downwards.
      * @param tagName          the tag name to apply to the files
      * @param scmTagParameters bean to pass some paramters for tagging {@link ScmTagParameters}
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @since 1.2
      */
@@ -689,7 +691,7 @@ public interface ScmProvider
      *
      * @param repository the source control system
      * @param fileSet    location of your local copy
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     UpdateScmResult update( ScmRepository repository, ScmFileSet fileSet )
@@ -701,7 +703,7 @@ public interface ScmProvider
      * @param repository the source control system
      * @param fileSet    location of your local copy
      * @param tag        use the version defined by the tag
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#update(org.apache.maven.scm.repository.ScmRepository,
      *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion)}
@@ -715,7 +717,7 @@ public interface ScmProvider
      * @param repository the source control system
      * @param fileSet    location of your local copy
      * @param version    use the version defined by the branch/tag/revision
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     UpdateScmResult update( ScmRepository repository, ScmFileSet fileSet, ScmVersion version )
@@ -728,7 +730,7 @@ public interface ScmProvider
      * @param fileSet      location of your local copy
      * @param tag          use the version defined by the tag
      * @param runChangelog Run the changelog command after the update
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#update(org.apache.maven.scm.repository.ScmRepository,
      *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, boolean)}
@@ -742,7 +744,7 @@ public interface ScmProvider
      * @param repository   the source control system
      * @param fileSet      location of your local copy
      * @param runChangelog Run the changelog command after the update
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     UpdateScmResult update( ScmRepository repository, ScmFileSet fileSet, boolean runChangelog )
@@ -755,7 +757,7 @@ public interface ScmProvider
      * @param fileSet      location of your local copy
      * @param version      use the version defined by the branch/tag/revision
      * @param runChangelog Run the changelog command after the update
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     UpdateScmResult update( ScmRepository repository, ScmFileSet fileSet, ScmVersion version, boolean runChangelog )
@@ -768,7 +770,7 @@ public interface ScmProvider
      * @param fileSet     location of your local copy
      * @param tag         use the version defined by the tag
      * @param datePattern the date pattern use in changelog output returned by scm tool
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#update(org.apache.maven.scm.repository.ScmRepository,
      *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, String)}
@@ -783,7 +785,7 @@ public interface ScmProvider
      * @param fileSet     location of your local copy
      * @param version     use the version defined by the branch/tag/revision
      * @param datePattern the date pattern use in changelog output returned by scm tool
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     UpdateScmResult update( ScmRepository repository, ScmFileSet fileSet, ScmVersion version, String datePattern )
@@ -795,8 +797,8 @@ public interface ScmProvider
      * @param repository the source control system
      * @param fileSet    location of your local copy
      * @param tag        use the version defined by the tag
-     * @param lastUpdate
-     * @return
+     * @param lastUpdate TODO
+     * @return TODO
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#update(org.apache.maven.scm.repository.ScmRepository,
      *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, java.util.Date)}
@@ -810,8 +812,8 @@ public interface ScmProvider
      * @param repository the source control system
      * @param fileSet    location of your local copy
      * @param version    use the version defined by the branch/tag/revision
-     * @param lastUpdate
-     * @return
+     * @param lastUpdate TODO
+     * @return TODO
      * @throws ScmException if any
      */
     UpdateScmResult update( ScmRepository repository, ScmFileSet fileSet, ScmVersion version, Date lastUpdate )
@@ -825,7 +827,7 @@ public interface ScmProvider
      * @param tag         use the version defined by the tag
      * @param lastUpdate  Date of last update
      * @param datePattern the date pattern use in changelog output returned by scm tool
-     * @return
+     * @return TODO
      * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#update(org.apache.maven.scm.repository.ScmRepository,
      *             org.apache.maven.scm.ScmFileSet, org.apache.maven.scm.ScmVersion, java.util.Date, String)}
@@ -842,7 +844,7 @@ public interface ScmProvider
      * @param version     use the version defined by the branch/tag/revision
      * @param lastUpdate  Date of last update
      * @param datePattern the date pattern use in changelog output returned by scm tool
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     UpdateScmResult update( ScmRepository repository, ScmFileSet fileSet, ScmVersion version, Date lastUpdate,
@@ -856,7 +858,7 @@ public interface ScmProvider
      *
      * @param repository the source control system
      * @param fileSet    the files to make editable
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     EditScmResult edit( ScmRepository repository, ScmFileSet fileSet )
@@ -869,7 +871,7 @@ public interface ScmProvider
      *
      * @param repository the source control system
      * @param fileSet    the files to make uneditable
-     * @return
+     * @return TODO
      * @throws ScmException if any
      */
     UnEditScmResult unedit( ScmRepository repository, ScmFileSet fileSet )
@@ -883,6 +885,7 @@ public interface ScmProvider
      * @param recursive  descend recursively
      * @param tag        use the version defined by the tag
      * @return the list of files in the repository
+     * @throws ScmException if any
      * @deprecated you must use {@link ScmProvider#list(org.apache.maven.scm.repository.ScmRepository,
      *             org.apache.maven.scm.ScmFileSet, boolean, org.apache.maven.scm.ScmVersion)}
      */
@@ -909,7 +912,7 @@ public interface ScmProvider
      * @param fileSet    location of your local copy
      * @param filename   file
      * @return blame for specified file
-     * @throws ScmException
+     * @throws ScmException if any
      * @since 1.4
      * @deprecated use blame with {@link BlameScmRequest} parameter
      */
@@ -918,9 +921,9 @@ public interface ScmProvider
 
     /**
      *
-     * @param blameScmRequest
+     * @param blameScmRequest TODO
      * @return blame for the file specified in the request
-     * @throws ScmException
+     * @throws ScmException if any
      * @since 1.8
      */
     BlameScmResult blame( BlameScmRequest blameScmRequest )
@@ -930,12 +933,12 @@ public interface ScmProvider
     /**
      * Create directory/directories in the repository.
      *
-     * @param repository
-     * @param fileSet
-     * @param createInLocal
-     * @param message
-     * @return
-     * @throws ScmException
+     * @param repository TODO
+     * @param fileSet TODO
+     * @param createInLocal TODO
+     * @param message TODO
+     * @return TODO
+     * @throws ScmException if any
      */
     MkdirScmResult mkdir( ScmRepository repository, ScmFileSet fileSet, String message, boolean createInLocal )
         throws ScmException;
@@ -945,7 +948,7 @@ public interface ScmProvider
      * @param fileSet    location of your local copy
      * @param parameters some parameters (not use currently but for future use)
      * @return if the scm implementation doesn't support "info" result will <code>null</code>
-     * @throws ScmException
+     * @throws ScmException if any
      * @since 1.5
      */
     InfoScmResult info( ScmProviderRepository repository, ScmFileSet fileSet, CommandParameters parameters )
@@ -956,7 +959,7 @@ public interface ScmProvider
      * @param fileSet    not use currently but for future use
      * @param parameters some parameters (not use currently but for future use)
      * @return if the scm implementation doesn't support "info" result will <code>null</code>
-     * @throws ScmException
+     * @throws ScmException if any
      * @since 1.6
      */
     RemoteInfoScmResult remoteInfo( ScmProviderRepository repository, ScmFileSet fileSet, CommandParameters parameters )
